@@ -8,7 +8,9 @@ import (
 	"time"
 
 	"github.com/AlecAivazis/survey/v2"
+	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/internal/codespaces/api"
+	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/spf13/cobra"
 	"golang.org/x/sync/errgroup"
 )
@@ -19,6 +21,8 @@ type deleteOptions struct {
 	codespaceName string
 	repoFilter    string
 	keepDays      uint16
+	orgName       string
+	userName      string
 
 	isInteractive bool
 	now           func() time.Time
@@ -39,11 +43,22 @@ func newDeleteCmd(app *App) *cobra.Command {
 
 	deleteCmd := &cobra.Command{
 		Use:   "delete",
-		Short: "Delete a codespace",
-		Args:  noArgsConstraint,
+		Short: "Delete codespaces",
+		Long: heredoc.Doc(`
+			Delete codespaces based on selection criteria.
+
+			All codespaces for the authenticated user can be deleted, as well as codespaces for a
+			specific repository. Alternatively, only codespaces older than N days can be deleted.
+
+			Organization administrators may delete any codespace billed to the organization.
+		`),
+		Args: noArgsConstraint,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if opts.deleteAll && opts.repoFilter != "" {
-				return errors.New("both --all and --repo is not supported")
+				return cmdutil.FlagErrorf("both `--all` and `--repo` is not supported")
+			}
+			if opts.orgName != "" && opts.codespaceName != "" && opts.userName == "" {
+				return cmdutil.FlagErrorf("using `--org` with `--codespace` requires `--user`")
 			}
 			return app.Delete(cmd.Context(), opts)
 		},
@@ -54,6 +69,8 @@ func newDeleteCmd(app *App) *cobra.Command {
 	deleteCmd.Flags().StringVarP(&opts.repoFilter, "repo", "r", "", "Delete codespaces for a `repository`")
 	deleteCmd.Flags().BoolVarP(&opts.skipConfirm, "force", "f", false, "Skip confirmation for codespaces that contain unsaved changes")
 	deleteCmd.Flags().Uint16Var(&opts.keepDays, "days", 0, "Delete codespaces older than `N` days")
+	deleteCmd.Flags().StringVarP(&opts.orgName, "org", "o", "", "The `login` handle of the organization (admin-only)")
+	deleteCmd.Flags().StringVarP(&opts.userName, "user", "u", "", "The `username` to delete codespaces for (used with --org)")
 
 	return deleteCmd
 }
@@ -63,14 +80,15 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 	nameFilter := opts.codespaceName
 	if nameFilter == "" {
 		a.StartProgressIndicatorWithLabel("Fetching codespaces")
-		codespaces, err = a.apiClient.ListCodespaces(ctx, -1)
+		codespaces, err = a.apiClient.ListCodespaces(ctx, -1, opts.orgName, opts.userName)
 		a.StopProgressIndicator()
 		if err != nil {
 			return fmt.Errorf("error getting codespaces: %w", err)
 		}
 
 		if !opts.deleteAll && opts.repoFilter == "" {
-			c, err := chooseCodespaceFromList(ctx, codespaces)
+			includeUsername := opts.orgName != ""
+			c, err := chooseCodespaceFromList(ctx, codespaces, includeUsername)
 			if err != nil {
 				return fmt.Errorf("error choosing codespace: %w", err)
 			}
@@ -78,7 +96,15 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 		}
 	} else {
 		a.StartProgressIndicatorWithLabel("Fetching codespace")
-		codespace, err := a.apiClient.GetCodespace(ctx, nameFilter, false)
+
+		var codespace *api.Codespace
+		var err error
+
+		if opts.orgName == "" || opts.userName == "" {
+			codespace, err = a.apiClient.GetCodespace(ctx, nameFilter, false)
+		} else {
+			codespace, err = a.apiClient.GetOrgMemberCodespace(ctx, opts.orgName, opts.userName, opts.codespaceName)
+		}
 		a.StopProgressIndicator()
 		if err != nil {
 			return fmt.Errorf("error fetching codespace information: %w", err)
@@ -132,7 +158,7 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 	for _, c := range codespacesToDelete {
 		codespaceName := c.Name
 		g.Go(func() error {
-			if err := a.apiClient.DeleteCodespace(ctx, codespaceName); err != nil {
+			if err := a.apiClient.DeleteCodespace(ctx, codespaceName, opts.orgName, opts.userName); err != nil {
 				a.errLogger.Printf("error deleting codespace %q: %v\n", codespaceName, err)
 				return err
 			}
