@@ -3,7 +3,6 @@ package extension
 import (
 	"bytes"
 	"fmt"
-	"io/ioutil"
 	"net/http"
 	"os"
 	"os/exec"
@@ -48,7 +47,7 @@ func TestHelperProcess(t *testing.T) {
 	os.Exit(0)
 }
 
-func newTestManager(dir string, client *http.Client, io *iostreams.IOStreams) *Manager {
+func newTestManager(dir string, client *http.Client, ios *iostreams.IOStreams) *Manager {
 	return &Manager{
 		dataDir:  func() string { return dir },
 		lookPath: func(exe string) (string, error) { return exe, nil },
@@ -56,15 +55,15 @@ func newTestManager(dir string, client *http.Client, io *iostreams.IOStreams) *M
 		newCommand: func(exe string, args ...string) *exec.Cmd {
 			args = append([]string{os.Args[0], "-test.run=TestHelperProcess", "--", exe}, args...)
 			cmd := exec.Command(args[0], args[1:]...)
-			if io != nil {
-				cmd.Stdout = io.Out
-				cmd.Stderr = io.ErrOut
+			if ios != nil {
+				cmd.Stdout = ios.Out
+				cmd.Stderr = ios.ErrOut
 			}
 			cmd.Env = []string{"GH_WANT_HELPER_PROCESS=1"}
 			return cmd
 		},
 		config: config.NewBlankConfig(),
-		io:     io,
+		io:     ios,
 		client: client,
 		platform: func() (string, string) {
 			return "windows-amd64", ".exe"
@@ -187,7 +186,7 @@ func TestManager_Remove(t *testing.T) {
 	err := m.Remove("hello")
 	assert.NoError(t, err)
 
-	items, err := ioutil.ReadDir(filepath.Join(tempDir, "extensions"))
+	items, err := os.ReadDir(filepath.Join(tempDir, "extensions"))
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(items))
 	assert.Equal(t, "gh-two", items[0].Name())
@@ -195,8 +194,8 @@ func TestManager_Remove(t *testing.T) {
 
 func TestManager_Upgrade_NoExtensions(t *testing.T) {
 	tempDir := t.TempDir()
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	err := m.Upgrade("", false)
 	assert.EqualError(t, err, "no extensions installed")
 	assert.Equal(t, "", stdout.String())
@@ -206,8 +205,8 @@ func TestManager_Upgrade_NoExtensions(t *testing.T) {
 func TestManager_Upgrade_NoMatchingExtension(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-hello", "gh-hello")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	err := m.Upgrade("invalid", false)
 	assert.EqualError(t, err, `no extension matched "invalid"`)
 	assert.Equal(t, "", stdout.String())
@@ -219,8 +218,8 @@ func TestManager_UpgradeExtensions(t *testing.T) {
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-hello", "gh-hello")))
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-two", "gh-two")))
 	assert.NoError(t, stubLocalExtension(tempDir, filepath.Join(tempDir, "extensions", "gh-local", "gh-local")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 3, len(exts))
@@ -249,8 +248,8 @@ func TestManager_UpgradeExtensions_DryRun(t *testing.T) {
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-hello", "gh-hello")))
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-two", "gh-two")))
 	assert.NoError(t, stubLocalExtension(tempDir, filepath.Join(tempDir, "extensions", "gh-local", "gh-local")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	m.EnableDryRunMode()
 	exts, err := m.list(false)
 	assert.NoError(t, err)
@@ -275,8 +274,8 @@ func TestManager_UpgradeExtension_LocalExtension(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubLocalExtension(tempDir, filepath.Join(tempDir, "extensions", "gh-local", "gh-local")))
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -290,8 +289,8 @@ func TestManager_UpgradeExtension_LocalExtension_DryRun(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubLocalExtension(tempDir, filepath.Join(tempDir, "extensions", "gh-local", "gh-local")))
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	m.EnableDryRunMode()
 	exts, err := m.list(false)
 	assert.NoError(t, err)
@@ -305,8 +304,8 @@ func TestManager_UpgradeExtension_LocalExtension_DryRun(t *testing.T) {
 func TestManager_UpgradeExtension_GitExtension(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-remote", "gh-remote")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -327,8 +326,8 @@ func TestManager_UpgradeExtension_GitExtension(t *testing.T) {
 func TestManager_UpgradeExtension_GitExtension_DryRun(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-remote", "gh-remote")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	m.EnableDryRunMode()
 	exts, err := m.list(false)
 	assert.NoError(t, err)
@@ -346,8 +345,8 @@ func TestManager_UpgradeExtension_GitExtension_Force(t *testing.T) {
 	tempDir := t.TempDir()
 	extensionDir := filepath.Join(tempDir, "extensions", "gh-remote")
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-remote", "gh-remote")))
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -369,12 +368,12 @@ func TestManager_UpgradeExtension_GitExtension_Force(t *testing.T) {
 func TestManager_MigrateToBinaryExtension(t *testing.T) {
 	tempDir := t.TempDir()
 	assert.NoError(t, stubExtension(filepath.Join(tempDir, "extensions", "gh-remote", "gh-remote")))
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 
 	reg := httpmock.Registry{}
 	defer reg.Verify(t)
 	client := http.Client{Transport: &reg}
-	m := newTestManager(tempDir, &client, io)
+	m := newTestManager(tempDir, &client, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -458,8 +457,8 @@ func TestManager_UpgradeExtension_BinaryExtension(t *testing.T) {
 			Tag:   "v1.0.1",
 		}))
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, &http.Client{Transport: &reg}, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, &http.Client{Transport: &reg}, ios)
 	reg.Register(
 		httpmock.REST("GET", "api/v3/repos/owner/gh-bin-ext/releases/latest"),
 		httpmock.JSONResponse(
@@ -520,8 +519,8 @@ func TestManager_UpgradeExtension_BinaryExtension_DryRun(t *testing.T) {
 			Tag:   "v1.0.1",
 		}))
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, &http.Client{Transport: &reg}, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, &http.Client{Transport: &reg}, ios)
 	m.EnableDryRunMode()
 	reg.Register(
 		httpmock.REST("GET", "api/v3/repos/owner/gh-bin-ext/releases/latest"),
@@ -573,8 +572,8 @@ func TestManager_UpgradeExtension_BinaryExtension_Pinned(t *testing.T) {
 			IsPinned: true,
 		}))
 
-	io, _, _, _ := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, _, _ := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.Nil(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -590,8 +589,8 @@ func TestManager_UpgradeExtenion_GitExtension_Pinned(t *testing.T) {
 	extDir := filepath.Join(tempDir, "extensions", "gh-remote")
 	assert.NoError(t, stubPinnedExtension(filepath.Join(extDir, "gh-remote"), "abcd1234"))
 
-	io, _, _, _ := iostreams.Test()
-	m := newTestManager(tempDir, nil, io)
+	ios, _, _, _ := iostreams.Test()
+	m := newTestManager(tempDir, nil, ios)
 	exts, err := m.list(false)
 	assert.NoError(t, err)
 	assert.Equal(t, 1, len(exts))
@@ -611,8 +610,8 @@ func TestManager_Install_git(t *testing.T) {
 	defer reg.Verify(t)
 	client := http.Client{Transport: &reg}
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(tempDir, &client, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(tempDir, &client, ios)
 
 	reg.Register(
 		httpmock.REST("GET", "repos/owner/gh-some-ext/releases/latest"),
@@ -644,8 +643,8 @@ func TestManager_Install_git_pinned(t *testing.T) {
 	defer reg.Verify(t)
 	client := http.Client{Transport: &reg}
 
-	io, _, _, stderr := iostreams.Test()
-	m := newTestManager(tempDir, &client, io)
+	ios, _, _, stderr := iostreams.Test()
+	m := newTestManager(tempDir, &client, ios)
 
 	reg.Register(
 		httpmock.REST("GET", "repos/owner/gh-cool-ext/releases/latest"),
@@ -705,10 +704,10 @@ func TestManager_Install_binary_pinned(t *testing.T) {
 		httpmock.REST("GET", "release/cool"),
 		httpmock.StringResponse("FAKE BINARY"))
 
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 	tempDir := t.TempDir()
 
-	m := newTestManager(tempDir, &http.Client{Transport: &reg}, io)
+	m := newTestManager(tempDir, &http.Client{Transport: &reg}, ios)
 
 	err := m.Install(repo, "v1.6.3-pre")
 	assert.NoError(t, err)
@@ -769,10 +768,10 @@ func TestManager_Install_binary_unsupported(t *testing.T) {
 				},
 			}))
 
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 	tempDir := t.TempDir()
 
-	m := newTestManager(tempDir, &client, io)
+	m := newTestManager(tempDir, &client, ios)
 
 	err := m.Install(repo, "")
 	assert.EqualError(t, err, "gh-bin-ext unsupported for windows-amd64. Open an issue: `gh issue create -R owner/gh-bin-ext -t'Support windows-amd64'`")
@@ -814,10 +813,10 @@ func TestManager_Install_binary(t *testing.T) {
 		httpmock.REST("GET", "release/cool"),
 		httpmock.StringResponse("FAKE BINARY"))
 
-	io, _, stdout, stderr := iostreams.Test()
+	ios, _, stdout, stderr := iostreams.Test()
 	tempDir := t.TempDir()
 
-	m := newTestManager(tempDir, &http.Client{Transport: &reg}, io)
+	m := newTestManager(tempDir, &http.Client{Transport: &reg}, ios)
 
 	err := m.Install(repo, "")
 	assert.NoError(t, err)
@@ -847,12 +846,12 @@ func TestManager_Install_binary(t *testing.T) {
 
 func TestManager_Create(t *testing.T) {
 	chdirTemp(t)
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(".", nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(".", nil, ios)
 
 	err := m.Create("gh-test", extensions.GitTemplateType)
 	assert.NoError(t, err)
-	files, err := ioutil.ReadDir("gh-test")
+	files, err := os.ReadDir("gh-test")
 	assert.NoError(t, err)
 	assert.Equal(t, []string{"gh-test"}, fileNames(files))
 
@@ -871,13 +870,13 @@ func TestManager_Create_go_binary(t *testing.T) {
 		httpmock.GraphQL(`query UserCurrent\b`),
 		httpmock.StringResponse(`{"data":{"viewer":{"login":"jillv"}}}`))
 
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(".", &http.Client{Transport: &reg}, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(".", &http.Client{Transport: &reg}, ios)
 
 	err := m.Create("gh-test", extensions.GoBinTemplateType)
 	require.NoError(t, err)
 
-	files, err := ioutil.ReadDir("gh-test")
+	files, err := os.ReadDir("gh-test")
 	require.NoError(t, err)
 	assert.Equal(t, []string{".github", ".gitignore", "main.go"}, fileNames(files))
 
@@ -888,7 +887,7 @@ func TestManager_Create_go_binary(t *testing.T) {
 		/gh-test.exe
 	`), string(gitignore))
 
-	files, err = ioutil.ReadDir(filepath.Join("gh-test", ".github", "workflows"))
+	files, err = os.ReadDir(filepath.Join("gh-test", ".github", "workflows"))
 	require.NoError(t, err)
 	assert.Equal(t, []string{"release.yml"}, fileNames(files))
 
@@ -904,21 +903,21 @@ func TestManager_Create_go_binary(t *testing.T) {
 
 func TestManager_Create_other_binary(t *testing.T) {
 	chdirTemp(t)
-	io, _, stdout, stderr := iostreams.Test()
-	m := newTestManager(".", nil, io)
+	ios, _, stdout, stderr := iostreams.Test()
+	m := newTestManager(".", nil, ios)
 
 	err := m.Create("gh-test", extensions.OtherBinTemplateType)
 	assert.NoError(t, err)
 
-	files, err := ioutil.ReadDir("gh-test")
+	files, err := os.ReadDir("gh-test")
 	assert.NoError(t, err)
 	assert.Equal(t, 2, len(files))
 
-	files, err = ioutil.ReadDir(filepath.Join("gh-test", ".github", "workflows"))
+	files, err = os.ReadDir(filepath.Join("gh-test", ".github", "workflows"))
 	assert.NoError(t, err)
 	assert.Equal(t, []string{"release.yml"}, fileNames(files))
 
-	files, err = ioutil.ReadDir(filepath.Join("gh-test", "script"))
+	files, err = os.ReadDir(filepath.Join("gh-test", "script"))
 	assert.NoError(t, err)
 	assert.Equal(t, []string{"build.sh"}, fileNames(files))
 
@@ -942,7 +941,7 @@ func chdirTemp(t *testing.T) {
 	})
 }
 
-func fileNames(files []os.FileInfo) []string {
+func fileNames(files []os.DirEntry) []string {
 	names := make([]string, len(files))
 	for i, f := range files {
 		names[i] = f.Name()
@@ -981,7 +980,7 @@ func stubPinnedExtension(path string, pinnedVersion string) error {
 }
 
 func stubLocalExtension(tempDir, path string) error {
-	extDir, err := ioutil.TempDir(tempDir, "local-ext")
+	extDir, err := os.MkdirTemp(tempDir, "local-ext")
 	if err != nil {
 		return err
 	}
